@@ -11,11 +11,17 @@ Classes:
 
 Functions:
 
-    KarnaughMapObject.create_map(tot_input=None, expression=None) -> (bool) success
-    KarnaughMapObject.print(object, file) -> (None)
-    KarnaughMapObject.to_string(object, file) -> (str) reader-friendly table
-    KarnaughMap.get_tot_variables(expression: str) -> (Union[int, None]) total number of variables
-    KarnaughMapObject.solve_map(self: object) -> (str) simplified binary logic representation of map
+    Public:
+        KarnaughMap.reset(self: _KMap) -> None
+        KarnaughMap.create_map(self: _KMap, tot_input: int = None, expression: str = None) -> (bool) success
+        KarnaughMap.print(self: _KMap) -> (None)
+        KarnaughMap.to_string(self: _KMap) -> (str) reader-friendly table
+        @staticmethod KarnaughMap.get_tot_variables(expression: str) -> (Union[int, None]) total number of variables
+        KarnaughMap.solve_map(self: _KMap) -> (str) simplified binary logic representation of map
+    Private:
+        @staticmethod KarnaughMap._evaluate_expression(equation: Union[str, List]) -> (str) The solution
+                                                                                        (bool True/False) as an integer
+                                                                                        string ("1"/"0")
 
 Misc variables:
 
@@ -27,7 +33,7 @@ Misc variables:
 
 __all__ = ["KarnaughMap"]
 __author__ = "Alexander Bisland"
-__version__ = "2.5.1"
+__version__ = "2.6.1"
 supported_from = "3.8.1"
 
 import re
@@ -38,8 +44,6 @@ _KMap = TypeVar("_KMap", bound="KarnaughMap")
 
 
 class KarnaughMap:  # TODO - map middle for 5+6
-    #                      - add CLI
-    #                      - add if __name__=="__main__":
     """Create Karnaugh Map objects which can be solved and manipulated.
     Supported characters:
         Any case is supported
@@ -49,11 +53,17 @@ class KarnaughMap:  # TODO - map middle for 5+6
 
     Functions:
 
-        KarnaughMapObject.create_map(tot_input=None, expression=None) -> (bool) success
-        KarnaughMapObject.print(object, file) -> (None)
-        KarnaughMapObject.to_string(object, file) -> (str) reader-friendly table
-        KarnaughMap.get_tot_variables(expression: str) -> (Union[int, None]) total number of variables
-        KarnaughMapObject.solve_map(self: object) -> (str) simplified binary logic representation of map
+        Public:
+            KarnaughMap.reset(self: _KMap) -> None
+            KarnaughMap.create_map(self: _KMap, tot_input: int = None, expression: str = None) -> (bool) success
+            KarnaughMap.print(self: _KMap) -> (None)
+            KarnaughMap.to_string(self: _KMap) -> (str) reader-friendly table
+            @staticmethod KarnaughMap.get_tot_variables(expression: str) -> (Union[int, None]) total number of variables
+            KarnaughMap.solve_map(self: _KMap) -> (str) simplified binary logic representation of map
+        Private:
+            @staticmethod KarnaughMap._evaluate_expression(equation: Union[str, List]) -> (str) The solution
+                                                                                            (bool True/False) as an
+                                                                                            integer string ("1"/"0")
 
     GLOBAL static variables:
 
@@ -100,11 +110,11 @@ class KarnaughMap:  # TODO - map middle for 5+6
             Returns:
                 Nothing (None): Null
         """
+        self.table = []
         self.tot_input = tot_input
         self.expression = expression
         self.valid_symbols = None
         self.debug = debug
-        self.table = []
         self.result = ""
         self.raise_error = raise_error
         self.groups = []
